"use strict";

exports.__esModule = true;
exports.createRule = createRule;

var _utils = require("@exah/utils");

var _utils2 = require("../utils");

function callAll(current) {
  for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    args[_key - 1] = arguments[_key];
  }

  var next = current.apply(void 0, args);
  return (0, _utils.isFn)(next) ? callAll.apply(void 0, [next].concat(args)) : next;
}
/**
 * ```js
 * import { createRule } from 'pss'
 * ```
 *
 * Create style from value. Must be used with {@link createStyles}.
 *
 * Related: {@link rule}.
 *
 * @param {Object} options
 *
 * @example
 * import pss, { createRule, spaceValue } from 'pss'
 *
 * const Box = styled.div(pss({
 *   gap: createRule({
 *     getStyle: (val) => ({ margin: val, padding: val }),
 *     getValue: spaceValue()
 *   })
 * }))
 *
 * @example
 * // Add theme to ThemeProvider
 * <ThemeProvider theme={theme}>
 *   <Box gap={1} /> // → margin: 8px; padding: 8px;
 * </ThemeProvider>
 */


function createRule(_ref) {
  var cssProp = _ref.cssProp,
      _ref$getStyle = _ref.getStyle,
      getStyle = _ref$getStyle === void 0 ? (0, _utils2.wrap)(cssProp) : _ref$getStyle,
      _ref$getValue = _ref.getValue,
      getValue = _ref$getValue === void 0 ? _utils.identity : _ref$getValue;
  return function (input, props, mediaKey) {
    var result = callAll(getValue, input, props, mediaKey);

    if ((0, _utils.isObj)(result)) {
      var themeMedia = (0, _utils2.getThemeMedia)(props);

      if ((0, _utils2.isMediaKey)((0, _utils2.getFirstKey)(result), themeMedia)) {
        return (0, _utils.mapObj)(function (key, value) {
          return (0, _utils2.wrapIfMedia)(themeMedia[key], getStyle(value, props));
        }, result);
      }
    } // not valid result


    if ((0, _utils.isBool)(result) || result == null) {
      // valid input fallback
      if ((0, _utils.isStr)(input) || (0, _utils.isNum)(input)) {
        return getStyle(input, props);
      }

      return null;
    }

    return getStyle(result, props);
  };
}