"use strict";

exports.__esModule = true;
exports.createStyles = createStyles;

var _utils = require("@exah/utils");

var _utils2 = require("../utils");

var _rule = require("./rule");

function createStyles(stylesMap) {
  function getStyles(props) {
    var themeMedia = (0, _utils2.getThemeMedia)(props);

    function mapStyles(_ref) {
      var input = _ref.input,
          style = _ref.style,
          selector = _ref.selector,
          mediaKey = _ref.mediaKey;

      // value with `theme.media` keys: { all: 0, M: 1 }
      // or selector { '&:first-child': 1 }
      if ((0, _utils.isObj)(input)) {
        return (0, _utils.mapObj)(function (key, value) {
          return (0, _utils2.isMediaKey)(key, themeMedia) ? mapStyles({
            input: value,
            style: style,
            selector: selector,
            mediaKey: key
          }) : mapStyles({
            input: value,
            style: style,
            selector: key,
            mediaKey: mediaKey
          });
        }, input);
      }

      var wrapper = (0, _utils.compose)((0, _utils2.wrapIfMedia)((0, _utils.path)([mediaKey])(themeMedia)), (0, _utils2.wrap)(selector));

      if ((0, _utils.isFn)(style)) {
        return wrapper(style(input, props, mediaKey));
      }

      if (input != null && input !== false) {
        return wrapper(style);
      }
    }

    return (0, _utils.reduceObj)(function (acc, name, input) {
      return acc.concat((0, _utils.toArr)(stylesMap[name]).map(function (style) {
        return mapStyles({
          input: input,
          style: style === true ? (0, _rule.rule)(name) : style
        });
      }));
    }, [], props);
  }

  return Object.assign(getStyles, {
    props: Object.keys(stylesMap),
    styles: stylesMap
  });
}