"use strict";

exports.__esModule = true;
exports.border = void 0;

var _core = require("../core");

var _values = require("../values");

var _internal = require("../.internal");

var _utils = require("../utils");

var borderRule = function borderRule(name) {
  return (0, _core.rule)(name, (0, _values.themeValue)({
    themeKey: 'border',
    transformValue: _utils.px
  }));
};
/**
 * ```js
 * import { border } from 'pss'
 * ```
 *
 * Set border with values from theme.
 *
 * prop           | css            | theme    | value | default
 * :--------------|:---------------|:---------|:------|:----------------------
 * `border`       | `border`       | `border` | ✓     | `theme.border.default`
 * `borderLeft`   | `border-left`  | `border` | ✓     | `theme.border.default`
 * `borderRight`  | `border-right` | `border` | ✓     | `theme.border.default`
 * `borderTop`    | `border-top`   | `border` | ✓     | `theme.border.default`
 * `borderBottom` | `border-bottom`| `border` | ✓     | `theme.border.default`
 *
 *
 * Related: {@link themeValue}, {@link rule},
 *
 * @param {Object} props
 *
 * @example
 * import { border } from 'pss'
 *
 * const Box = styled.div`
 *   ${border}
 * `
 *
 * @example
 * <Box border='1px dotted red' /> // → border: 1px dotted red
 * <Box borderBottom='divider' /> // → theme.border.divider // → border-bottom: 1px dotted #f5f5f5
 */


var border = (0, _internal.directionStyles)({
  cssProp: 'border',
  rule: borderRule
});
exports.border = border;