"use strict";

exports.__esModule = true;
exports.boxSelfAlignment = exports.boxItemsAlignment = exports.boxContentAlignment = void 0;

var _core = require("../core");

var boxContentAlignment = (0, _core.createStyles)({
  alignContent: true,
  justifyContent: true
});
/**
 * ```js
 * import { boxItemsAlignment } from 'pss'
 * ```
 *
 * prop             | css               | theme | value | default
 * :----------------|:------------------|:------|:------|:------
 * `alignItems`     | `align-items`     | —     | ✓     | —
 * `justifyItems`   | `justify-items`   | —     | ✓     | —
 *
 * Related: {@link rule}
 *
 * @param {Object} props
 *
 * @example
 * import { boxItemsAlignment } from 'pss'
 *
 * const Grid = styled.div`
 *   display: grid;
 *   ${boxItemsAlignment}
 * `
 *
 * @example
 * <Grid alignItems='center'>
 *   <div>1</div>
 *   <div>2</div>
 * </Grid>
 */

exports.boxContentAlignment = boxContentAlignment;
var boxItemsAlignment = (0, _core.createStyles)({
  alignItems: true,
  justifyItems: true
});
/**
 * ```js
 * import { boxSelfAlignment } from 'pss'
 * ```
 *
 * prop          | css            | theme     | value | default
 * :-------------|:---------------|:----------|:------|:--------
 * `alignSelf`   | `align-self`   | —         | ✓     | —
 * `justifySelf` | `justify-self` | —         | ✓     | —
 *
 * Related: {@link rule}
 *
 * @param {Object} props
 *
 * @example
 * import { boxSelfAlignment } from 'pss'
 *
 * const Box = styled.div`
 *   ${boxSelfAlignment}
 * `
 *
 * @example
 * <Grid>
 *   <Box alignSelf='center'>1</Box>
 * </Grid>
 */

exports.boxItemsAlignment = boxItemsAlignment;
var boxSelfAlignment = (0, _core.createStyles)({
  justifySelf: true,
  alignSelf: true
});
exports.boxSelfAlignment = boxSelfAlignment;