"use strict";

exports.__esModule = true;
exports.gridContainer = exports.createGridContainer = void 0;

var _core = require("../core");

var _values = require("../values");

var _utils = require("../utils");

var createGridContainer = function createGridContainer(prefix) {
  var _createStyles;

  return (0, _core.createStyles)((_createStyles = {
    grid: (0, _core.rule)('grid')
  }, _createStyles[(0, _utils.addPrefix)(prefix, 'autoFlow')] = (0, _core.rule)('gridAutoFlow'), _createStyles[(0, _utils.addPrefix)(prefix, 'autoRows')] = (0, _core.rule)('gridAutoRows'), _createStyles[(0, _utils.addPrefix)(prefix, 'autoColumns')] = (0, _core.rule)('gridAutoColumns'), _createStyles[(0, _utils.addPrefix)(prefix, 'template')] = (0, _core.rule)('gridTemplate', (0, _values.themeValue)({
    themeKey: 'gridTemplate'
  })), _createStyles[(0, _utils.addPrefix)(prefix, 'templateRows')] = (0, _core.rule)('gridTemplateRows'), _createStyles[(0, _utils.addPrefix)(prefix, 'templateColumns')] = (0, _core.rule)('gridTemplateColumns'), _createStyles[(0, _utils.addPrefix)(prefix, 'templateAreas')] = (0, _core.rule)('gridTemplateAreas'), _createStyles));
};
/**
 * ```js
 * import { gridContainer } from 'pss'
 * ```
 *
 * [Grid Layout Container](https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Grid_Layout) styles.
 *
 * prop                  | css                     | theme          | value | default
 * :------------------ --|:------------------------|:---------------|:------|:-------
 * `grid`                | `grid`                  | —              | ✓     | —
 * `gridAutoFlow`        | `grid-auto-flow`        | —              | ✓     | —
 * `gridAutoColumns`     | `grid-auto-columns`     | —              | ✓     | —
 * `gridAutoRows`        | `grid-auto-rows`        | —              | ✓     | —
 * `gridTemplate`        | `grid-template`         | `gridTemplate` | ✓     | `theme.gridTemplate.default`
 * `gridTemplateColumns` | `grid-template-columns` | —              | ✓     | —
 * `gridTemplateRows`    | `grid-template-rows`    | —              | ✓     | —
 * `gridTemplateAreas`   | `grid-template-areas`   | —              | ✓     | —
 *
 * Related: {@link gap}, {@link flex}, {@link rule}
 *
 * @param {Object} props
 *
 * @example
 * import { gridContainer } from 'pss'
 *
 * const Grid = styled.div`
 *   display: grid;
 *   ${gridContainer}
 * `
 *
 * @example
 * <Grid gridTemplateColumns='repeat(12, 1fr)'> // display: grid; grid-template-columns: repeat(12, 1fr)
 *   <div>1</div>
 *   <div>2</div>
 * </Grid>
 */


exports.createGridContainer = createGridContainer;
var gridContainer = createGridContainer('grid');
exports.gridContainer = gridContainer;