"use strict";

exports.__esModule = true;
exports.outline = void 0;

var _core = require("../core");

var randomHexColor = function randomHexColor() {
  return '#' + ((Math.random() * 0xFFFFFF << 0).toString(16) + '0').slice(0, 6);
};
/**
 * ```js
 * import { outline } from 'pss'
 * ```
 *
 * prop         | css        | theme | value | default
 * :------------|:-----------|:------|:------|:----------
 * `outline`    | `outline`  | —     | ✓     | —
 *
 * \* Random hex color, useful for debugging layout
 *
 * Related: {@link rule}.
 *
 * @param {Object} props
 *
 * @example
 * import { outline } from 'pss'
 *
 * const Box = styled.div`
 *   ${outline}
 * `
 *
 * @example
 * <Box outline='1px solid red' /> // → outline: 1px solid red
 */


var outline = (0, _core.createStyles)({
  outline: (0, _core.rule)('outline', function (val) {
    return val === 'debug' ? "1px solid " + randomHexColor() : val;
  })
});
exports.outline = outline;