"use strict";

exports.__esModule = true;
exports.overflowValue = overflowValue;
exports.overflow = void 0;

var _utils = require("@exah/utils");

var _core = require("../core");

var touchStyle = {
  WebkitOverflowScrolling: 'touch'
};

var notTouch = function notTouch(item) {
  return item !== 'touch';
};

function overflowValue(input) {
  if ((0, _utils.isStr)(input)) {
    var parsed = input.split(/\s+/);
    var values = parsed.filter(notTouch);
    var isTouch = parsed.length !== values.length;

    if (values.length === 1) {
      return Object.assign({
        overflow: values[0]
      }, isTouch && touchStyle);
    }

    return Object.assign({
      overflowX: values[0],
      overflowY: values[1]
    }, isTouch && touchStyle);
  }
}
/**
 * ```js
 * import { overflow } from 'pss'
 * ```
 *
 * Shorthand for `overflow-x`, `overflow-y` and `-webkit-overflow-scrolling`.
 *
 * Related: {@link style}.
 *
 * @param {Object} props
 *
 * @example
 * import { overflow } from 'pss'
 *
 * const Box = styled.div`
 *   ${overflow}
 * `
 *
 * @example
 * <Box overflow='hidden' /> // overflow: hidden
 * <Box overflow='hidden auto' /> // overflow-x: hidden; overflow-y: auto
 * <Box overflow='auto touch' /> // overflow: auto; -webkit-overflow-scrolling: touch
 */


var overflow = (0, _core.style)({
  prop: 'overflow',
  getValue: overflowValue
});
exports.overflow = overflow;