"use strict";

exports.__esModule = true;
exports.createPercentageValue = createPercentageValue;
exports.percentageValue = void 0;

var _utils = require("@exah/utils");

var _utils2 = require("../utils");

var percentage = function percentage(n) {
  return n > 0 && n <= 1 ? n * 100 + "%" : n;
};

function createPercentageValue(_ref) {
  var _ref$transformValue = _ref.transformValue,
      transformValue = _ref$transformValue === void 0 ? _utils.identity : _ref$transformValue;
  return function (defaultValue) {
    if (defaultValue === void 0) {
      defaultValue = transformValue;
    }

    return function (input) {
      return (0, _utils.isNum)(input) ? transformValue(percentage(input)) : defaultValue;
    };
  };
}
/**
 * ```js
 * import { percentageValue } from 'pss'
 * ```
 *
 * Related: {@link sizes}, {@link rule}, {@link sizeValue}.
 *
 * @return {Function} - that must be used in {@link rule}
 *
 * @example
 * import pss, { rule, percentageValue } from 'pss'
 *
 * const sizes = pss({
 *   w: rule('width', percentageValue())
 * })
 *
 * const Box = styled.div`
 *   ${sizes}
 * `
 *
 * @example
 * <Box w={1} /> // → width: 100%
 * <Box w={1 / 2} /> // → width: 50%
 * <Box w={0} /> // → width: 0
 * <Box w={100} /> // → width: 100px
 */


var percentageValue = createPercentageValue({
  transformValue: _utils2.px
});
exports.percentageValue = percentageValue;