import { DEFAULT_MEDIA_KEY } from '../constants';
import { wrapIfMedia, getMedia } from '../utils';
/**
 * ```js
 * import { mediaStyle } from 'pss'
 * ```
 *
 * Create style wrapped in `theme.media`.
 *
 * Related: {@link display}.
 *
 * @example
 * import pss, { mediaStyle } from 'pss'
 *
 * const Box = styled.div(pss({
 *   hide: mediaStyle({ display: 'none' })
 * }))
 *
 * @example
 * // Create theme with media queries
 * const theme = {
 *   media: {
 *     sm: '(max-width: 600px)'
 *   }
 * }
 *
 * <ThemeProvider theme={theme}>
 *   <Box hide='sm' /> // @media (max-width: 600px) { display: 'none' }
 * </ThemeProvider>
 */

export var mediaStyle = function mediaStyle(style) {
  return function (input, props, propMediaKey) {
    if (!input) return null;
    if (propMediaKey != null && input === true) return style;
    var mediaKey = input === true ? DEFAULT_MEDIA_KEY : input;
    var media = getMedia(mediaKey)(props);
    if (media == null && input !== true) return null;
    return wrapIfMedia(media, style);
  };
};