import { themeValue } from '../values/theme-value';
import { createStyles } from './create-styles';
import { createRule } from './create-rule';
/**
 * ```js
 * import { style } from 'pss'
 * ```
 *
 * Create style for single prop.
 * Combines {@link createStyles} and {@link createRule} in single function.
 * Inspired by [`styled-system`](https://github.com/jxnblk/styled-system).
 *
 * @param {Object} options
 *
 * @example
 * import pss, { style } from 'pss'
 *
 * const opacity = style({
 *   cssProp: 'opacity'
 * })
 *
 * const Box = styled.div`
 *   ${opacity}
 * `
 *
 * @example
 * <Box opacity={0.5} /> // → opacity: 0.5
 */

export var style = function style(_ref) {
  var _createStyles;

  var cssProp = _ref.cssProp,
      themeKey = _ref.themeKey,
      transformValue = _ref.transformValue,
      scale = _ref.scale,
      getter = _ref.getter,
      _ref$prop = _ref.prop,
      prop = _ref$prop === void 0 ? cssProp : _ref$prop,
      _ref$getValue = _ref.getValue,
      getValue = _ref$getValue === void 0 ? themeKey ? themeValue({
    themeKey: themeKey,
    transformValue: transformValue,
    scale: scale,
    getter: getter
  }) : undefined : _ref$getValue;
  return createStyles((_createStyles = {}, _createStyles[prop] = createRule({
    cssProp: cssProp,
    getValue: getValue
  }), _createStyles));
};