import { getMedia } from '../utils';
/**
 * ```js
 * import { mq } from 'pss'
 * ```
 *
 * @param [mediaKey] — key in `theme.media`
 *
 * @example
 * import { mq, themePath } from 'pss'
 *
 * const Box = styled.div`
 *   \@media ${mq('sm')} {
 *     background-color: ${themePath('color.red', 'hotpink')};
 *   }
 * `
 *
 * <Box /> // → @media (max-width: 600px) { background-color: red; }
 */

export var mq = function mq(mediaKey, fallback) {
  if (fallback === void 0) {
    fallback = 'all';
  }

  return function (props) {
    return getMedia(mediaKey)(props) || fallback;
  };
};