import { createStyles, rule } from '../core';
import { themeValue } from '../values';
import { addPrefix } from '../utils';
export var createGridContainer = function createGridContainer(prefix) {
  var _createStyles;

  return createStyles((_createStyles = {
    grid: rule('grid')
  }, _createStyles[addPrefix(prefix, 'autoFlow')] = rule('gridAutoFlow'), _createStyles[addPrefix(prefix, 'autoRows')] = rule('gridAutoRows'), _createStyles[addPrefix(prefix, 'autoColumns')] = rule('gridAutoColumns'), _createStyles[addPrefix(prefix, 'template')] = rule('gridTemplate', themeValue({
    themeKey: 'gridTemplate'
  })), _createStyles[addPrefix(prefix, 'templateRows')] = rule('gridTemplateRows'), _createStyles[addPrefix(prefix, 'templateColumns')] = rule('gridTemplateColumns'), _createStyles[addPrefix(prefix, 'templateAreas')] = rule('gridTemplateAreas'), _createStyles));
};
/**
 * ```js
 * import { gridContainer } from 'pss'
 * ```
 *
 * [Grid Layout Container](https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Grid_Layout) styles.
 *
 * prop                  | css                     | theme          | value | default
 * :------------------ --|:------------------------|:---------------|:------|:-------
 * `grid`                | `grid`                  | —              | ✓     | —
 * `gridAutoFlow`        | `grid-auto-flow`        | —              | ✓     | —
 * `gridAutoColumns`     | `grid-auto-columns`     | —              | ✓     | —
 * `gridAutoRows`        | `grid-auto-rows`        | —              | ✓     | —
 * `gridTemplate`        | `grid-template`         | `gridTemplate` | ✓     | `theme.gridTemplate.default`
 * `gridTemplateColumns` | `grid-template-columns` | —              | ✓     | —
 * `gridTemplateRows`    | `grid-template-rows`    | —              | ✓     | —
 * `gridTemplateAreas`   | `grid-template-areas`   | —              | ✓     | —
 *
 * Related: {@link gap}, {@link flex}, {@link rule}
 *
 * @param {Object} props
 *
 * @example
 * import { gridContainer } from 'pss'
 *
 * const Grid = styled.div`
 *   display: grid;
 *   ${gridContainer}
 * `
 *
 * @example
 * <Grid gridTemplateColumns='repeat(12, 1fr)'> // display: grid; grid-template-columns: repeat(12, 1fr)
 *   <div>1</div>
 *   <div>2</div>
 * </Grid>
 */

export var gridContainer = createGridContainer('grid');