import { isStr } from '@exah/utils';
import { style } from '../core';
var touchStyle = {
  WebkitOverflowScrolling: 'touch'
};

var notTouch = function notTouch(item) {
  return item !== 'touch';
};

export function overflowValue(input) {
  if (isStr(input)) {
    var parsed = input.split(/\s+/);
    var values = parsed.filter(notTouch);
    var isTouch = parsed.length !== values.length;

    if (values.length === 1) {
      return Object.assign({
        overflow: values[0]
      }, isTouch && touchStyle);
    }

    return Object.assign({
      overflowX: values[0],
      overflowY: values[1]
    }, isTouch && touchStyle);
  }
}
/**
 * ```js
 * import { overflow } from 'pss'
 * ```
 *
 * Shorthand for `overflow-x`, `overflow-y` and `-webkit-overflow-scrolling`.
 *
 * Related: {@link style}.
 *
 * @param {Object} props
 *
 * @example
 * import { overflow } from 'pss'
 *
 * const Box = styled.div`
 *   ${overflow}
 * `
 *
 * @example
 * <Box overflow='hidden' /> // overflow: hidden
 * <Box overflow='hidden auto' /> // overflow-x: hidden; overflow-y: auto
 * <Box overflow='auto touch' /> // overflow: auto; -webkit-overflow-scrolling: touch
 */

export var overflow = style({
  prop: 'overflow',
  getValue: overflowValue
});